macro_rules! dbg {
($val:expr $(,)?) => { ... };
($($val:expr),+ $(,)?) => { ... };
}Expand description
Prints and returns the value of a given expression for quick and dirty debugging
macro_rules! dbg {
($val:expr $(,)?) => { ... };
($($val:expr),+ $(,)?) => { ... };
}Prints and returns the value of a given expression for quick and dirty debugging