macro_rules! kernel_module {
(
type: $ty:ty,
name: $name:literal,
$(description: $description:literal,)?
$(author: $author:literal,)?
license: $license:tt$(,)?
) => { ... };
}Available on crate feature
full only.Expand description
Registers a kernel module with the kernel.
The type argument should be a type implementing the Module trait.
Additionally, it also takes the following arguments in order:
name- a user facing name for the moduledescription(optional) - a user facing description of the moduleauthor(optional) - the author of the modulelicense- An SPDX license identifier (currently onlyMPL-*is accepted)
Examples
See the module-level documentation.